<?php

/**
 * @file
 * Administrative UI and functions for the OpenID Connect module.
 */

/**
 * Form builder: Main administrative form.
 */
function openid_connect_admin_form($form, &$form_state) {
  $form['#attached']['css'][] = drupal_get_path('module', 'openid_connect') . '/css/sso-button.css';
  $form['#attached']['js'][] = drupal_get_path('module', 'openid_connect') . '/js/ssoButtonPreview.js';

  $client_plugins = openid_connect_get_plugins();
  $options = array();
  foreach ($client_plugins as $client_plugin) {
    $options[$client_plugin['name']] = $client_plugin['title'];
  }

  $form['#tree'] = TRUE;
  $form['openid_connect_clients_enabled'] = array(
    '#title' => t('Enable PixelPin'),
    '#type' => 'checkboxes',
    '#options' => array('pixelpin' => t('Enable')),
    '#default_value' => variable_get('openid_connect_clients_enabled', array()),
  );
  foreach ($client_plugins as $client_plugin) {
    $client = openid_connect_get_client($client_plugin['name']);

    $element = 'openid_connect_clients_enabled[' . $client_plugin['name'] . ']';
    $form['clients'][$client_plugin['name']] = array(
      '#title' => $client_plugin['title'],
      '#type' => 'fieldset',
      '#states' => array(
        'visible' => array(
          ':input[name="' . $element . '"]' => array('checked' => TRUE),
        ),
      ),
    );
    $form['clients'][$client_plugin['name']] += $client->settingsForm();
  }

  $form['openid_connect_always_save_userinfo'] = array(
    '#title' => t('Save user claims on every login'),
    '#description' => t('If disabled, user claims will only be saved when the account is first created.'),
    '#type' => 'checkbox',
    '#default_value' => variable_get('openid_connect_always_save_userinfo', TRUE),
  );

  $ppssoVariables = variable_get('openid_connect_ppsso_customise', $default = NULL);

  $form['ppsso_customise'] = array(
    '#title' => t('Change the way the pixelpin log in button looks'),
    '#type' => 'fieldset',
  );

  $form['ppsso_customise']['openid_connect_ppsso_customise_enable'] = array(
      '#type' => 'select',
      '#title' => 'Do you want to customise the way the log in button looks?',
      '#options' => ['No','Yes'],
      '#attributes' => array('onchange' => 'toggleppssopreview();'),
      '#default_value' => $ppssoVariables['enabled']
  );

  $form['ppsso_customise']['openid_connect_ppsso_customise_size'] = array(
      '#type' => 'select',
      '#title' => 'Log In Button Size',
      '#options' => ['Large', 'Medium', 'Small'],
      '#default_value' => $ppssoVariables['size'],
      '#attributes' => array('onchange' => 'toggleppssopreview();'),
      '#states' => array(
        'visible' => array(
          'select[name="ppsso_customise[openid_connect_ppsso_customise_enable]"]' => array('value' => '1')
        )
      ),
  );

  $form['ppsso_customise']['openid_connect_ppsso_customise_colour'] = array(
      '#type' => 'select',
      '#title' => 'Log In Button Colour',
      '#options' => ['Purple', 'Cyan', 'Pink', 'White'],
      '#default_value' => $ppssoVariables['colour'],
      '#attributes' => array('onchange' => 'toggleppssopreview();'),
      '#states' => array(
        'visible' => array(
          'select[name="ppsso_customise[openid_connect_ppsso_customise_enable]"]' => array('value' => '1')
        )
      ),
  );

  $form['ppsso_customise']['openid_connect_ppsso_customise_show_text'] = array(
      '#type' => 'select',
      '#title' => 'Do you want the button to contain text?',
      '#options' => ['Yes', 'No'],
      '#default_value' => $ppssoVariables['showText'],
      '#attributes' => array('onchange' => 'toggleppssopreview();'),
      '#states' => array(
        'visible' => array(
          'select[name="ppsso_customise[openid_connect_ppsso_customise_enable]"]' => array('value' => '1')
        )
      ),
  );

  $form['ppsso_customise']['openid_connect_ppsso_customise_login_text'] = array(
      '#title' => t('Login Button Text'),
      '#type' => 'textfield',
      '#default_value' => $ppssoVariables['loginText'],
      '#attributes' => array('onchange' => 'toggleppssopreview();'),
      '#states' => array(
        'visible' => array(
          'select[name="ppsso_customise[openid_connect_ppsso_customise_enable]"]' => array('value' => '1'),
          'select[name="ppsso_customise[openid_connect_ppsso_customise_show_text]"]' => array('value' => '0')
        ),
      ),
  );

  $form['ppsso_customise']['openid_connect_ppsso_customise_register_text'] = array(
      '#title' => t('Register Button Text'),
      '#type' => 'textfield',
      '#default_value' => $ppssoVariables['registerText'],
      '#states' => array(
        'visible' => array(
          'select[name="ppsso_customise[openid_connect_ppsso_customise_enable]"]' => array('value' => '1'),
          'select[name="ppsso_customise[openid_connect_ppsso_customise_show_text]"]' => array('value' => '0')
        ),
      ),
  );

  $customSsoButton = variable_get('openid_connect_ppsso_customise');

  if($customSsoButton['sampleButton']){
    $sampleSsoButton = $ppssoVariables['sampleButton'];
  } else {
    $sampleSsoButton = '<button name="pixelpin" id="previewSSObutton" class="ppsso-btn">Log in with <span class="ppsso-logotype">PixelPin</span></button>';
  }

  if($customSsoButton['loginButton']){
    $liveSsoButton = $ppssoVariables['loginButton'];
  } else {
    $liveSsoButton = '<button name="pixelpin" id="edit-openid-connect-client-pixelpin-login-front-page" class="ppsso-btn">Log in with <span class="ppsso-logotype">PixelPin</span></button>';
  }

  $form['ppsso_customise']['openid_connect_client_pixelpin_preview_sso_styling_label'] = array(
    '#markup' => t('<label>Preview PixelPin SSO Styling </label>')
  );

  $form['ppsso_customise']['openid_connect_client_pixelpin_preview_sso_styling'] = array(
    '#markup' => t($sampleSsoButton)
  );

  $form['ppsso_customise']['openid_connect_client_pixelpin_live_sso_styling_label'] = array(
    '#markup' => t('<label>Live PixelPin SSO Styling </label>')
  );

   $form['ppsso_customise']['openid_connect_client_pixelpin_live_sso_styling'] = array(
    '#title' => t('Live PixelPin SSO Styling'),
    '#markup' => t($liveSsoButton)
  );

  $form['userinfo_mapping'] = array(
    '#title' => t('User claims mapping'),
    '#type' => 'fieldset',
  );

  $user_entity_wrapper = entity_metadata_wrapper('user');
  $claims = openid_connect_claims_options();
  $properties = $user_entity_wrapper->getPropertyInfo();
  $properties_skip = _openid_connect_user_properties_to_skip();
  foreach ($properties as $property_name => $property) {
    if (isset($properties_skip[$property_name])) {
      continue;
    }
    // Always map the timezone.
    $default_value = 0;
    if ($property_name == 'timezone') {
      $default_value = 'zoneinfo';
    }
    if ($property_name == 'field_family_name_pixelpin') {
      $default_value = 'family_name';
    }
    if ($property_name == 'field_given_name_pixelpin') {
      $default_value = 'given_name';
    }
    if ($property_name == 'field_nickname_pixelpin') {
      $default_value = 'nickname';
    }
    if ($property_name == 'field_preferred_username_pixelpin') {
      $default_value = 'preferred_username';
    }

    $form['userinfo_mapping']['openid_connect_userinfo_mapping_property_' . $property_name] = array(
      '#type' => 'select',
      '#title' => $property['label'],
      '#description' => $property['description'],
      '#options' => $claims,
      '#empty_value' => 0,
      '#empty_option' => t('- No mapping -'),
      '#default_value' => variable_get('openid_connect_userinfo_mapping_property_' . $property_name, $default_value),
    );
  }

  $form['actions']['#type'] = 'actions';
  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save configuration'),
  );

  return $form;
}

/**
 * Validation handler for openid_connect_admin_form.
 */
function openid_connect_admin_form_validate($form, &$form_state) {
  $enabled_clients = $form_state['values']['openid_connect_clients_enabled'];
  $enabled_clients = array_filter($enabled_clients);
  foreach ($enabled_clients as $client_name) {
    // Give the client a chance to validate the submitted values.
    $client = openid_connect_get_client($client_name);
    $fake_form = $form['clients'][$client_name];
    $fake_form_state = array('values' => $form_state['values']['clients'][$client_name]);
    $error_element_base = 'clients][' . $client_name . '][';
    $client->settingsFormValidate($fake_form, $fake_form_state, $error_element_base);
  }
}

/**
 * Submit handler for openid_connect_admin_form.
 */
function openid_connect_admin_form_submit($form, &$form_state) {
  $enabled_clients = $form_state['values']['openid_connect_clients_enabled'];
  $enabled_clients = array_filter($enabled_clients);
  variable_set('openid_connect_clients_enabled', $enabled_clients);

  drupal_set_message(t("Configuration saved."), 'status');

  foreach ($enabled_clients as $client_name) {
    // Give the client a chance to modify the submitted values.
    $client = openid_connect_get_client($client_name);
    $fake_form = $form['clients'][$client_name];
    $fake_form_state = array('values' => $form_state['values']['clients'][$client_name]);
    $client->settingsFormSubmit($fake_form, $fake_form_state);

    // Save the settings.
    variable_set('openid_connect_client_' . $client_name, $fake_form_state['values']);
  }

  $claims = array();
  foreach ($form_state['values']['userinfo_mapping'] as $variable => $claim) {
    if (!empty($claim)) {
      $claims[] = $claim;
      variable_set($variable, $claim);
    }
    else {
      variable_del($variable);
    }
  }
  if (!empty($claims)) {
    variable_set('openid_connect_userinfo_mapping_claims', $claims);
  }
  else {
    variable_del('openid_connect_userinfo_mapping_claims');
  }

  $default_enabled = array(
    'openid_connect_always_save_userinfo'
  );
  foreach ($default_enabled as $variable) {
    if (isset($form_state['values'][$variable]) && empty($form_state['values'][$variable])) {
      variable_set($variable, $form_state['values'][$variable]);
    }
  }

  $ppssoCustomiseEnabled = $form_state['values']['ppsso_customise']['openid_connect_ppsso_customise_enable'];
  $ppssoCustomiseSize = $form_state['values']['ppsso_customise']['openid_connect_ppsso_customise_size'];
  $ppssoCustomiseColour = $form_state['values']['ppsso_customise']['openid_connect_ppsso_customise_colour'];
  $ppssoCustomiseShowText = $form_state['values']['ppsso_customise']['openid_connect_ppsso_customise_show_text'];
  $ppssoCustomiseLoginText = $form_state['values']['ppsso_customise']['openid_connect_ppsso_customise_login_text'];
  $ppssoCustomiseRegisterText = $form_state['values']['ppsso_customise']['openid_connect_ppsso_customise_register_text'];

  if($ppssoCustomiseEnabled === '1'){
      if($ppssoCustomiseShowText === '0'){
        switch ($ppssoCustomiseSize){
          case 0:
            $customSsoButtonSize = '';
            break;
          case 1:
            $customSsoButtonSize = 'ppsso-md';
            break;
          case 2:
            $customSsoButtonSize = 'ppsso-sm';
            break;
        }
      } else {
        switch ($ppssoCustomiseSize){
          case 0:
            $customSsoButtonSize = 'ppsso-logo-lg';
            break;
          case 1:
            $customSsoButtonSize = 'ppsso-md ppsso-logo-md';
            break;
          case 2:
            $customSsoButtonSize = 'ppsso-sm ppsso-logo-sm';
            break;
        }
      }

      switch ($ppssoCustomiseColour){
        case 0:
          $customSsoColour = '';
          break;
        case 1:
          $customSsoColour = 'ppsso-cyan';
          break;
        case 2:
          $customSsoColour = 'ppsso-pink';
          break;
        case 3:
          $customSsoColour = 'ppsso-white';
          break;
      }


      $connectSsoButton = '<button name="pixelpin" id="previewSSObutton" class="ppsso-btn ' . $customSsoButtonSize . ' ' . $customSsoColour .'">Connect with <span class="ppsso-logotype">PixelPin</span></button>';
      $disconnectSsoButton = '<button name="pixelpin" id="previewSSObutton" class="ppsso-btn ' . $customSsoButtonSize . ' ' . $customSsoColour .'">Disconnect from <span class="ppsso-logotype">PixelPin</span></button>';

      if($ppssoCustomiseShowText === '0'){
        $loginSsoButton = '<button name="pixelpin" id="edit-openid-connect-client-pixelpin-login" type="submit" class="ppsso-btn ' . $customSsoButtonSize . ' ' . $customSsoColour .'">' . $ppssoCustomiseLoginText .' <span class="ppsso-logotype">PixelPin</span></button>';
        $registerSsoButton = '<button name="pixelpin" id="edit-openid-connect-client-pixelpin-register" type="submit" class="ppsso-btn ' . $customSsoButtonSize . ' ' . $customSsoColour .'">' . $ppssoCustomiseRegisterText .' <span class="ppsso-logotype">PixelPin</span></button>';
        $sampleSsoButton = '<button name="pixelpin" id="previewSSObutton" class="ppsso-btn ' . $customSsoButtonSize . ' ' . $customSsoColour .'">' . $ppssoCustomiseLoginText .' <span class="ppsso-logotype">PixelPin</span></button>';
      } else {
        $loginSsoButton = '<button name="pixelpin" id="edit-openid-connect-client-pixelpin-login" type="submit" class="ppsso-btn ' . $customSsoButtonSize . ' ' . $customSsoColour .'"></button>';
        $registerSsoButton = '<button name="pixelpin" id="edit-openid-connect-client-pixelpin-login-front-page" type="submit" class="ppsso-btn ' . $customSsoButtonSize . ' ' . $customSsoColour .'"></button>';
        $sampleSsoButton = '<button name="pixelpin" id="previewSSObutton" class="ppsso-btn ' . $customSsoButtonSize . ' ' . $customSsoColour .'"></button>';
      }
    } else {
      $loginSsoButton = NULL;
      $registerSsoButton = NULL;
      $sampleSsoButton = NULL;
      $connectSsoButton = NULL;
      $disconnectSsoButton = NULL;
    }

  $ppsso = array(
    'enabled' => $ppssoCustomiseEnabled,
    'size' => $ppssoCustomiseSize,
    'colour' => $ppssoCustomiseColour,
    'showText' => $ppssoCustomiseShowText,
    'loginText' => $ppssoCustomiseLoginText,
    'registerText' => $ppssoCustomiseRegisterText,
    'loginButton' => $loginSsoButton,
    'registerButton' => $registerSsoButton,
    'sampleButton' => $sampleSsoButton,
    'connectButton' => $connectSsoButton,
    'disconnectButton' => $disconnectSsoButton
  );

  variable_set('openid_connect_ppsso_customise', $ppsso);
}
